==> quasardb-3.13.6.post1-cp38-cp38-macosx_10_14_x86_64.whl: quasardb/cmake_install.cmake <==
# Install script for directory: /Users/teamcity/buildAgent/work/283bde3fda0d76e7/thirdparty

# Set the install prefix
if(NOT DEFINED CMAKE_INSTALL_PREFIX)
  set(CMAKE_INSTALL_PREFIX "/usr/local")
endif()
string(REGEX REPLACE "/$" "" CMAKE_INSTALL_PREFIX "${CMAKE_INSTALL_PREFIX}")

# Set the install configuration name.
if(NOT DEFINED CMAKE_INSTALL_CONFIG_NAME)
  if(BUILD_TYPE)
    string(REGEX REPLACE "^[^A-Za-z0-9_]+" ""
           CMAKE_INSTALL_CONFIG_NAME "${BUILD_TYPE}")
  else()
    set(CMAKE_INSTALL_CONFIG_NAME "Release")
  endif()
  message(STATUS "Install configuration: \"${CMAKE_INSTALL_CONFIG_NAME}\"")
endif()

# Set the component getting installed.
if(NOT CMAKE_INSTALL_COMPONENT)
  if(COMPONENT)
    message(STATUS "Install component: \"${COMPONENT}\"")
    set(CMAKE_INSTALL_COMPONENT "${COMPONENT}")
  else()
    set(CMAKE_INSTALL_COMPONENT)
  endif()
endif()

# Is this installation the result of a crosscompile?
if(NOT DEFINED CMAKE_CROSSCOMPILING)
  set(CMAKE_CROSSCOMPILING "FALSE")
endif()

# Set default install directory permissions.
if(NOT DEFINED CMAKE_OBJDUMP)
  set(CMAKE_OBJDUMP "/Library/Developer/CommandLineTools/usr/bin/objdump")
endif()

if(NOT CMAKE_INSTALL_LOCAL_ONLY)
  # Include the install script for each subdirectory.
  include("/Users/teamcity/buildAgent/work/283bde3fda0d76e7/build/lib.macosx-12.0-x86_64-cpython-38/quasardb/date/cmake_install.cmake")
  include("/Users/teamcity/buildAgent/work/283bde3fda0d76e7/build/lib.macosx-12.0-x86_64-cpython-38/quasardb/pybind11/cmake_install.cmake")
  include("/Users/teamcity/buildAgent/work/283bde3fda0d76e7/build/lib.macosx-12.0-x86_64-cpython-38/quasardb/range-v3/cmake_install.cmake")

endif()

==> quasardb-3.14.0-cp38-cp38-macosx_10_14_x86_64.whl: quasardb/cmake_install.cmake <==
# Install script for directory: /Users/teamcity/buildAgent/work/283bde3fda0d76e7/thirdparty

# Set the install prefix
if(NOT DEFINED CMAKE_INSTALL_PREFIX)
  set(CMAKE_INSTALL_PREFIX "/usr/local")
endif()
string(REGEX REPLACE "/$" "" CMAKE_INSTALL_PREFIX "${CMAKE_INSTALL_PREFIX}")

# Set the install configuration name.
if(NOT DEFINED CMAKE_INSTALL_CONFIG_NAME)
  if(BUILD_TYPE)
    string(REGEX REPLACE "^[^A-Za-z0-9_]+" ""
           CMAKE_INSTALL_CONFIG_NAME "${BUILD_TYPE}")
  else()
    set(CMAKE_INSTALL_CONFIG_NAME "Release")
  endif()
  message(STATUS "Install configuration: \"${CMAKE_INSTALL_CONFIG_NAME}\"")
endif()

# Set the component getting installed.
if(NOT CMAKE_INSTALL_COMPONENT)
  if(COMPONENT)
    message(STATUS "Install component: \"${COMPONENT}\"")
    set(CMAKE_INSTALL_COMPONENT "${COMPONENT}")
  else()
    set(CMAKE_INSTALL_COMPONENT)
  endif()
endif()

# Is this installation the result of a crosscompile?
if(NOT DEFINED CMAKE_CROSSCOMPILING)
  set(CMAKE_CROSSCOMPILING "FALSE")
endif()

# Set default install directory permissions.
if(NOT DEFINED CMAKE_OBJDUMP)
  set(CMAKE_OBJDUMP "/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/objdump")
endif()

if(NOT CMAKE_INSTALL_LOCAL_ONLY)
  # Include the install script for each subdirectory.
  include("/Users/teamcity/buildAgent/work/283bde3fda0d76e7/build/lib.macosx-12.0-x86_64-cpython-38/quasardb/date/cmake_install.cmake")
  include("/Users/teamcity/buildAgent/work/283bde3fda0d76e7/build/lib.macosx-12.0-x86_64-cpython-38/quasardb/pybind11/cmake_install.cmake")
  include("/Users/teamcity/buildAgent/work/283bde3fda0d76e7/build/lib.macosx-12.0-x86_64-cpython-38/quasardb/range-v3/cmake_install.cmake")

endif()
